@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2002,2003 Nikos Mavroyanopoulos
+ *  Copyright (C) 2004 Free Software Foundation
  *
  *  This file is part of GNUTLS.
  *
@@ -28,6 +29,7 @@
 #include <gnutls_datum.h>
 #include <gnutls_rsa_export.h>
 #include "x509/x509.h"
+#include "x509/privkey.h"
 #include "debug.h"
 
 /* This function takes a number of bits and returns a supported
@@ -43,7 +45,6 @@
 const GNUTLS_MPI* _gnutls_get_rsa_params(gnutls_rsa_params rsa_params)
 {
 	if (rsa_params == NULL) {
-		gnutls_assert();
 		return NULL;
 	}
 
@@ -201,6 +202,20 @@ void gnutls_rsa_params_deinit(gnutls_rsa_params rsa_params)
 	gnutls_x509_privkey_deinit(rsa_params);
 }
 
+/**
+  * gnutls_rsa_params_cpy - This function will copy an RSA parameters structure
+  * @dst: Is the destination structure, which should be initialized.
+  * @src: Is the source structure
+  *
+  * This function will copy the RSA parameters structure from source
+  * to destination.
+  *
+  **/
+int gnutls_rsa_params_cpy(gnutls_rsa_params dst, gnutls_rsa_params src)
+{
+	return gnutls_x509_privkey_cpy( dst, src);
+}
+
 /**
   * gnutls_rsa_params_generate2 - This function will generate temporary RSA parameters
   * @params: The structure where the parameters will be stored
