@@ -88,8 +88,11 @@ void libtasn1_perror(asn1_retCode error)
   * libtasn1_strerror - Returns a string with a description of an error
   * @error: is an error returned by a libtasn1 function.
   *
-  * This function is similar to strerror(). The only difference is that it 
-  * accepts an error (number) returned by a libasn1 function. 
+  * This function is similar to strerror(). The only difference is that it
+  * accepts an error (number) returned by a libasn1 function.
+  *
+  * Returns: Pointer to static zero-terminated string describing error
+  *   code.
   **/
 const char* libtasn1_strerror(asn1_retCode error)
 {
@@ -114,6 +117,8 @@ void _libtasn1_log( const char *fmt, ...) {
  va_end(args);   
 
  fprintf(stderr, str);
+
+ return;
 }
 #else /* not DEBUG */
 # ifndef C99_MACROS
@@ -124,4 +129,3 @@ void _libtasn1_log( const char *fmt, ...) {
 void _libtasn1_null_log( void* x, ...) { return; }
 # endif /* C99_MACROS */
 #endif /* DEBUG */
-
